﻿using System;
using System.Collections.Generic;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using Microsoft.Phone.Controls;
using System.IO.IsolatedStorage;

namespace TranslatorTest
{
    public partial class MainPage : PhoneApplicationPage
    {
        // Constructor
        public MainPage()
        {
            InitializeComponent();
        }

        private void btnTranslate_Click(object sender, RoutedEventArgs e)
        {
            Translator.LanguageServiceClient client = new Translator.LanguageServiceClient();
            // 翻訳が完了したらTextBlockに翻訳後の文章を設定する
            client.TranslateCompleted += (sx, ex) => { textAfter.Text = ex.Result; };
            // TextBoxに入力した文章を英語から日本語への翻訳を行う
            client.TranslateAsync("{Bing AppID}", textBefore.Text, "en", "ja", null, null); 
        }

        private void btnSpeak_Click(object sender, RoutedEventArgs e)
        {
            // 翻訳後のテキストがTextBlockにあるか判定
            if (string.IsNullOrEmpty(textAfter.Text))
            {
                MessageBox.Show("翻訳を行ってください.");
                return;
            }

            // MediaElementの初期化
            mediaElement.Source = null;

            Translator.LanguageServiceClient client = new Translator.LanguageServiceClient();
            // waveファイルの作成完了後、サーバーからwaveファイルをダウンロードする
            client.SpeakCompleted += (sx, ex) => {
                if (ex.Error != null) return;

                WebClient wc = new WebClient();
                wc.OpenReadCompleted += wc_OpenReadCompleted;
                wc.OpenReadAsync(new Uri(ex.Result, UriKind.Absolute));
            };
            // TextBlockに入力した文章の読ませたwaveファイルの作成を行う
            client.SpeakAsync("{Bing AppID}", textBefore.Text, "ja", null, null); 
        }

        void wc_OpenReadCompleted(object sender, OpenReadCompletedEventArgs e)
        {
            if (e.Error != null) return;

            string fileName = "translate_test.wav";
            var store = IsolatedStorageFile.GetUserStoreForApplication();

            // 以前に作成したファイルが残っている場合は削除する
            if (store.FileExists(fileName))
            {
                store.DeleteFile(fileName);
            }

            // 読み込んだストリームを分離ストレージのファイルに書き出す
            using (var strm = store.CreateFile(fileName))
            {
                var bytes = new byte[256*1024];
                while (true)
                {
                    int read = e.Result.Read(bytes, 0, bytes.Length);
                    if (read <= 0) break;
                    strm.Write(bytes, 0, read);
                }

                // 指定されたストリームを使ってSourceプロパティに設定します
                mediaElement.SetSource(strm);
                // 設定されたSourceの再生の開始
                mediaElement.Play();
            }
        }
    }
}